@@ -42,8 +42,8 @@ sub probe ($$) {
         # hwRamStatus N.A.
         #
         if ($obj->{-name} =~ m/\.hwRamMax$/) {
-            my $hwRamMax    = undef;
-            my $hwRamStatus = undef;
+            my $hwRamMax;
+            my $hwRamStatus;
 
             #   local workspace
             my $out; my $raw;
@@ -62,8 +62,8 @@ sub probe ($$) {
         # hwRamStatus N.A.
         #
         if ($obj->{-name} =~ m/\.hwRamMax$/) {
-            my $hwRamMax    = undef;
-            my $hwRamStatus = undef;
+            my $hwRamMax;
+            my $hwRamStatus;
 
             #   local workspace
             my $out; my $raw;
@@ -84,8 +84,8 @@ sub probe ($$) {
         #FIXME set prtdiag cache expiry to "forever" when cache supports multiple caching times
         #
         if ($obj->{-name} =~ m/\.hwRam(Max|Status)$/) {
-            my $hwRamMax    = undef;
-            my $hwRamStatus = undef;
+            my $hwRamMax;
+            my $hwRamStatus;
 
             #   local workspace
             my $out; my $raw; my $n2i; my @dat; my $arch;
