@@ -64,7 +64,7 @@ sub probe ($$) {
             $sysVMRamMax = int(&mem_rounded($sysctl->{"hw.physmem"}) / (1024*1024));
 
             #   determine sysVMRamFree
-            my $sysVMRamFree =
+            $sysVMRamFree =
                 int((  $sysctl->{"hw.pagesize"}
                      * (  $sysctl->{"vm.stats.vm.v_inactive_count"} 
                         + $sysctl->{"vm.stats.vm.v_cache_count"}
