@@ -203,11 +203,11 @@ sub run ($$;$) {
     $expires = "1m" if (not defined($expires));
     my $result = $self->{-cache}->fetch($cmd);
     if (defined($result)) {
-        $self->{-log}->printf(4, "system: run: \"$cmd\" ($expires) [CACHE HIT]");
+        $self->{-log}->printf(4, "system: run: \"%s\" ($expires) [CACHE HIT]", $cmd);
     }
     else {
-        $self->{-log}->printf(3, "system: run: \"$cmd\" ($expires) [CACHE MISS]");
-        $self->{-log}->printf(5, "system: executing command: \"$cmd\"");
+        $self->{-log}->printf(3, "system: run: \"%s\" ($expires) [CACHE MISS]", $cmd);
+        $self->{-log}->printf(5, "system: executing command: \"%s\"", $cmd);
         $result = { -stdout => '', -rv => 0 };
         $result->{-stdout} = `$cmd 2>/dev/null`;
         $result->{-rv} = ($? >> 8);
@@ -495,6 +495,7 @@ my $opt = {
     'logfile'   => "@localstatedir@/snmpdx.log",
     'loglevel'  => 9,
     'strict'    => 0,
+    'openpkg'   => "@openpkg@",
 };
 
 #   command line parsing
@@ -514,6 +515,7 @@ my %options = (
     'l|logfile=s'   => \$opt->{'logfile'},
     'L|loglevel=i'  => \$opt->{'loglevel'},
     'S|strict'      => \$opt->{'strict'},
+    'O|openpkg'     => \$opt->{'openpkg'},
 );
 Getopt::Long::Configure("bundling");
 my $result = GetOptions(%options) || die "option parsing failed";
@@ -534,7 +536,8 @@ if ($opt->{'help'}) {
           " -m,--mibname=MIB    the name of the MIB to act under\n" .
           " -l,--logfile=PATH   path to daemon logfile\n" .
           " -L,--loglevel=NUM   logging level (0...9)\n" .
-          " -S,--strict         strict processing of unknown values\n";
+          " -S,--strict         strict processing of unknown values\n" .
+          " -O,--openpkg        OpenPKG instance to use for swOp, swBind\n";
     exit(0);
 }
 if ($opt->{'version'}) {
@@ -550,6 +553,10 @@ if (-f $opt->{'config'}) {
         $line =~ s|\r?\n$||s;
         next if ($line =~ m/^\s*(#.*)?$/s);
         my ($option, $value) = ($line =~ m|^\s*(\S+)\s+(.+?)\s*$|s);
+        if ($value =~ m|^".*"$| or $value =~ m|^'.*'$|) {
+            $value =~ s|^.||;
+            $value =~ s|.$||;
+        }
         die "invalid configuration line \"$line\""
             if (not defined($option) or not defined($value));
         my ($var) = map  { $options{$_} }
